@@ -1,6 +1,5 @@
 use warnings; use strict;
 require Test::More;
-use String::Diff;
 use File::Spec;
 use File::Basename;
 my $trepanpl = File::Spec->catfile(dirname(__FILE__), qw(.. bin trepan.pl));
@@ -9,10 +8,15 @@ my $debug = $^W;
 package Helper;
 use File::Basename qw(dirname); use File::Spec;
 use English qw( -no_match_vars ) ;
+
+
+# Runs debugger in subshell. 0 is returned if everything went okay.
+# nonzero if something went wrong.
 sub run_debugger($$;$$)
 {
     my ($test_invoke, $cmd_filename, $right_filename, $opts) = @_;
-    $opts //= {};
+    $opts = {} unless defined $opts;
+    $opts->{do_test} = 1 unless exists $opts->{do_test};
     Test::More::note( "running $test_invoke with $cmd_filename" );
     my $run_opts = $opts->{run_opts} || "--basename --nx --no-highlight";
     my $full_cmd_filename = File::Spec->catfile(dirname(__FILE__), 
@@ -28,11 +32,14 @@ sub run_debugger($$;$$)
     $run_opts .= " --testing $full_cmd_filename" unless ($opts->{no_cmdfile});
     $right_filename = $ext_file->('right') unless defined($right_filename);
     my $cmd = "$EXECUTABLE_NAME $trepanpl $run_opts $test_invoke";
-    print $cmd, "\n" if $debug;
+    print $cmd, "\n"  if $debug;
     my $output = `$cmd`;
-    print $output if $debug;
+    print "$output\n" if $debug;
     my $rc = $? >> 8;
-    Test::More::is($rc, 0, 'Debugger command executed successfully');
+    if ($opts->{do_test}) {
+	Test::More::is($rc, 0, 'Debugger command executed successfully');
+    }
+    return $rc if $rc;
     open(RIGHT_FH, "<$right_filename");
     undef $INPUT_RECORD_SEPARATOR;
     my $right_string = <RIGHT_FH>;
@@ -41,19 +48,30 @@ sub run_debugger($$;$$)
     $got_filename = $ext_file->('got');
     # TODO : Perhaps make sure we optionally use eq_or_diff from 
     # Test::Differences here.
-    if (Test::More::is($right_string, $output, 'Output comparison')) {
+    my $equal_output = $right_string eq $output;
+    Test::More::ok($right_string eq $output, 'Output comparison') 
+	if $opts->{do_test};
+    if ($equal_output) {
         unlink $got_filename;
+	return 0;
     } else {
-        my $diff = String::Diff::diff_merge($output, $right_string);
-
         open (GOT_FH, '>', $got_filename)
             or die "Cannot open '$got_filename' for writing - $OS_ERROR";
         print GOT_FH $output;
         close GOT_FH;
-
-        Test::More::diag($diff);
+        Test::More::diag("Compare $got_filename with $right_filename:");
+	my $output = `diff -u $right_filename $got_filename 2>&1`;
+	my $rc = $? >> 8;
+	# GNU diff returns 0 if files are equal, 1 if different and 2
+	# if something went wrong. We also should take care of the
+	# case where diff isn't installed. So although we expect a 1
+	# for GNU diff, we'll also take accept 0, but any other return
+	# code means some sort of failure.
+	$output = `diff $right_filename $got_filename 2>&1` 
+	     if ($rc > 1) || ($rc < 0) ;
+        Test::More::diag($output);
+	return 1;
     }
-    return;
 }
 
 1;
